@@ -551,7 +551,7 @@ namespace gnote {
   {
     if(NoteTagTable::tag_is_serializable(tag)) {
       DBG_OUT("BufferTagApplied queueing save: %s", tag->property_name().get_value().c_str());
-      queue_save(CONTENT_CHANGED);
+      queue_save(get_tag_table()->get_change_type(tag));
     }
   }
 
@@ -561,7 +561,7 @@ namespace gnote {
   {
     if(NoteTagTable::tag_is_serializable(tag)) {
       DBG_OUT("BufferTagRemoved queueing save: %s", tag->property_name().get_value().c_str());
-      queue_save(CONTENT_CHANGED);
+      queue_save(get_tag_table()->get_change_type(tag));
     }
   }
 
@@ -1060,10 +1060,10 @@ namespace gnote {
 
   std::string Note::text_content()
   {
-    if(m_buffer) {
-      return m_buffer->get_slice(m_buffer->begin(), m_buffer->end());
+    if(!m_buffer) {
+      get_buffer();
     }
-    return utils::XmlDecoder::decode(xml_content());
+    return m_buffer->get_slice(m_buffer->begin(), m_buffer->end());
   }
 
   void Note::set_text_content(const std::string & text)
