@@ -1,6 +1,7 @@
 /*
  * gnote
  *
+ * Copyright (C) 2011 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -30,17 +31,20 @@
 #include <gtkmm/treeiter.h>
 #include <gtkmm/liststore.h>
 #include <gtkmm/combobox.h>
+#include <gtkmm/comboboxtext.h>
+
+#include "sharp/addinstreemodel.hpp"
 
 namespace gnote {
 
 class SyncServiceAddin;
-
+class AddinManager;
 
 class PreferencesDialog
   : public Gtk::Dialog
 {
 public:
-  PreferencesDialog();
+  PreferencesDialog(AddinManager & addinmanager);
   
 
   Gtk::Widget *make_editing_pane();
@@ -54,6 +58,8 @@ private:
   Gtk::Label *make_label (const std::string & label_text/*, params object[] args*/);
   Gtk::CheckButton *make_check_button (const std::string & label_text);
 
+  void enable_addin(bool enable);
+
   void open_template_button_clicked();
   void on_font_button_clicked();
   void update_font_button(const std::string & font_desc);
@@ -62,13 +68,21 @@ private:
   void on_reset_sync_addin_button();
   void on_save_sync_addin_button();
 
+  void on_preferences_setting_changed(const Glib::ustring & key);
+  void on_rename_behavior_changed();
+
+  sharp::DynamicModule * get_selected_addin();
   void on_addin_tree_selection_changed();
   void update_addin_buttons();
   void load_addins();
   void on_enable_addin_button();
   void on_disable_addin_button();
   void on_addin_prefs_button();
+  bool addin_pref_dialog_deleted(GdkEventAny*, Gtk::Dialog*);
+  void addin_pref_dialog_response(int, Gtk::Dialog*);
   void on_addin_info_button();
+  bool addin_info_dialog_deleted(GdkEventAny*, Gtk::Dialog*);
+  void addin_info_dialog_response(int, Gtk::Dialog*);
 ////
 
   class SyncStoreModel
@@ -92,13 +106,15 @@ private:
   Gtk::Widget *syncAddinPrefsWidget;
   Gtk::Button *resetSyncAddinButton;
   Gtk::Button *saveSyncAddinButton;
-  //AddinManager addin_manager;
+  Gtk::ComboBoxText *renameBehaviorCombo;
+  AddinManager &m_addin_manager;
     
   Gtk::Button *font_button;
   Gtk::Label  *font_face;
   Gtk::Label  *font_size;
 
-  //Mono.Addins.Gui.AddinTreeWidget addin_tree;
+  Gtk::TreeView              *m_addin_tree;
+  sharp::AddinsTreeModel::Ptr m_addin_tree_model;
   
   Gtk::Button *enable_addin_button;
   Gtk::Button *disable_addin_button;
@@ -110,20 +126,16 @@ private:
   Gtk::RadioButton overwriteOnConflictRadio;
 
 
-  /// <summary>
   /// Keep track of the opened addin prefs dialogs so other windows
   /// can be interacted with (as opposed to opening these as modal
   /// dialogs).
   ///
   /// Key = Mono.Addins.Addin.Id
-  /// </summary>
-  std::map<std::string, Gtk::Dialog> addin_prefs_dialogs;
+  std::map<std::string, Gtk::Dialog* > addin_prefs_dialogs;
 
-  /// <summary>
   /// Used to keep track of open AddinInfoDialogs.
   /// Key = Mono.Addins.Addin.Id
-  /// </summary>
-  std::map<std::string, Gtk::Dialog> addin_info_dialogs;
+  std::map<std::string, Gtk::Dialog* > addin_info_dialogs;
 
 };
 
