@@ -27,6 +27,7 @@
 
 #include <glibmm/i18n.h>
 #include <gtkmm/image.h>
+#include <gtkmm/linkbutton.h>
 #include <gtkmm/main.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/table.h>
@@ -92,11 +93,11 @@ namespace gnote {
     : utils::ForcedPresentWindow(_("Search All Notes"))
     , m_manager(m)
     , m_menubar(NULL)
-    , m_find_combo(Gtk::ListStore::create(m_find_combo_columns), 0)
+    , m_find_combo(Glib::RefPtr<Gtk::TreeModel>::cast_static(Gtk::ListStore::create(m_find_combo_columns)), true)
     , m_clear_search_button(Gtk::Stock::CLEAR)
-    , m_case_sensitive(_("C_ase Sensitive"), true)
     , m_content_vbox(false, 0)
     , m_matches_column(NULL)
+    , m_no_matches_box(NULL)
     , m_tree(NULL)
     , m_entry_changed_timeout(NULL)
     , m_clickX(0), m_clickY(0)
@@ -110,12 +111,11 @@ namespace gnote {
 
     m_menubar = create_menu_bar ();
 
-    Gtk::Image *image = manage(new Gtk::Image (utils::get_icon ("system-search", 48)));
-
     Gtk::Label *label = manage(new Gtk::Label (_("_Search:"), true));
     label->property_xalign() = 1;
 
     label->set_mnemonic_widget(m_find_combo);
+    m_find_combo.set_entry_text_column(0);
     m_find_combo.signal_changed()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_entry_changed));
     m_find_combo.get_entry()->set_activates_default(false);
@@ -135,13 +135,9 @@ namespace gnote {
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::clear_search_clicked));
     m_clear_search_button.show ();
 
-    m_case_sensitive.signal_toggled()
-      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_case_sensitive_toggled));
-
     Gtk::Table *table = manage(new Gtk::Table (2, 3, false));
     table->attach (*label, 0, 1, 0, 1, Gtk::SHRINK, (Gtk::AttachOptions)0, 0, 0);
     table->attach (m_find_combo, 1, 2, 0, 1);
-    table->attach (m_case_sensitive, 1, 2, 1, 2);
     table->attach (m_clear_search_button,
                   2, 3, 0, 1,
                   Gtk::SHRINK, (Gtk::AttachOptions)0, 0, 0);
@@ -149,11 +145,9 @@ namespace gnote {
     table->show_all ();
 
     Gtk::HBox *hbox = manage(new Gtk::HBox (false, 2));
-    hbox->set_border_width(8);
-    hbox->pack_start (*image, false, false, 4);
     hbox->pack_start (*table, true, true, 0);
     hbox->show_all ();
-            
+
     // Notebooks Pane
     Gtk::Widget *notebooksPane = Gtk::manage(make_notebooks_pane ());
     notebooksPane->show ();
@@ -162,12 +156,12 @@ namespace gnote {
     m_tree = manage(m_tree);
     m_tree->show ();
 
-    m_status_bar.set_has_resize_grip(true);
+    set_has_resize_grip(true);
     m_status_bar.show();
 
     // Update on changes to notes
-    m.signal_note_deleted.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notes_changed));
-    m.signal_note_added.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notes_changed));
+    m.signal_note_deleted.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_deleted));
+    m.signal_note_added.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_added));
     m.signal_note_renamed.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_renamed));
     m.signal_note_saved.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_saved));
 
@@ -176,13 +170,6 @@ namespace gnote {
 
     m_matches_window.set_shadow_type(Gtk::SHADOW_IN);
 
-    // Reign in the window size if there are notes with long
-    // names, or a lot of notes...
-
-    int h, w;
-    m_tree->get_size_request (h,w);
-    m_matches_window.set_size_request(std::min(h, 420), std::min(w, 480));
-                        
     m_matches_window.property_hscrollbar_policy() = Gtk::POLICY_AUTOMATIC;
     m_matches_window.property_vscrollbar_policy() = Gtk::POLICY_AUTOMATIC;
     m_matches_window.add (*m_tree);
@@ -220,9 +207,31 @@ namespace gnote {
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_added_to_notebook));
     notebooks::NotebookManager::instance().signal_note_removed_from_notebook()
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_note_removed_from_notebook));
+
+    // Set the focus chain for the top-most containers
+    std::vector<Gtk::Widget*> focus_chain;
+    focus_chain.push_back(hbox);
+    focus_chain.push_back(&m_hpaned);
+    vbox->set_focus_chain(focus_chain);
+
+    // Set focus chain for sub widgets of first top-most container
+    focus_chain.clear();
+    focus_chain.push_back(&m_find_combo);
+    focus_chain.push_back(&m_matches_window);
+    hbox->set_focus_chain(focus_chain);
+
+    // set focus chain for sub widgets of second top-most container
+    focus_chain.clear();
+    focus_chain.push_back(&m_matches_window);
+    focus_chain.push_back(notebooksPane);
+    m_hpaned.set_focus_chain(focus_chain);
+
+    // get back to the beginning of the focus chain
+    focus_chain.clear();
+    focus_chain.push_back(m_tree);
+    m_matches_window.set_focus_chain(focus_chain);
                         
-    Gtk::Main::signal_quit()
-      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_exiting_event));
+    Gnote::obj().signal_quit.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_exiting_event));
 
   }
 
@@ -343,7 +352,7 @@ namespace gnote {
       sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_button_released));
     m_tree->signal_key_press_event().connect(
       sigc::mem_fun(*this,
-                    &NoteRecentChanges::on_treeview_key_pressed));
+                    &NoteRecentChanges::on_treeview_key_pressed), false);
     m_tree->signal_drag_data_get().connect(
       sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_drag_data_get));
 
@@ -354,6 +363,7 @@ namespace gnote {
 
     Gtk::TreeViewColumn *title = manage(new Gtk::TreeViewColumn ());
     title->set_title(_("Note"));
+    title->set_min_width(150);
     title->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
     title->set_expand(true);
     title->set_resizable(true);
@@ -366,7 +376,7 @@ namespace gnote {
     static_cast<Gtk::CellRendererText*>(renderer)->property_ellipsize() = Pango::ELLIPSIZE_END;
     title->pack_start (*renderer, true);
     title->add_attribute (*renderer, "text", 1 /* title */);
-    title->set_sort_column_id(1); /* title */
+    title->set_sort_column(1); /* title */
     title->set_sort_indicator(false);
     title->set_reorderable(false);
     title->set_sort_order(Gtk::SORT_ASCENDING);
@@ -382,7 +392,7 @@ namespace gnote {
     renderer->property_xalign() = 1.0;
     change->pack_start (*renderer, false);
     change->add_attribute (*renderer, "text", 2 /* change date */);
-    change->set_sort_column_id(2); /* change date */
+    change->set_sort_column(2); /* change date */
     change->set_sort_indicator(false);
     change->set_reorderable(false);
     change->set_sort_order(Gtk::SORT_DESCENDING);
@@ -390,6 +400,42 @@ namespace gnote {
     m_tree->append_column (*change);
   }
 
+  void NoteRecentChanges::add_note(const Note::Ptr & note)
+  {
+    std::string nice_date =
+      utils::get_pretty_print_date(note->change_date(), true);
+    Gtk::TreeIter iter = m_store->append();
+    iter->set_value(m_column_types.icon, s_note_icon);
+    iter->set_value(m_column_types.title, note->get_title());
+    iter->set_value(m_column_types.change_date, nice_date);
+    iter->set_value(m_column_types.note, note);
+  }
+
+  void NoteRecentChanges::delete_note(const Note::Ptr & note)
+  {
+    Gtk::TreeModel::Children rows = m_store->children();
+
+    for (Gtk::TreeModel::iterator iter = rows.begin();
+         rows.end() != iter; iter++) {
+      if (note == iter->get_value(m_column_types.note)) {
+        m_store->erase(iter);
+        break;
+      }
+    }
+  }
+
+  void NoteRecentChanges::rename_note(const Note::Ptr & note)
+  {
+    Gtk::TreeModel::Children rows = m_store->children();
+
+    for (Gtk::TreeModel::iterator iter = rows.begin();
+         rows.end() != iter; iter++) {
+      if (note == iter->get_value(m_column_types.note)) {
+        iter->set_value(m_column_types.title, note->get_title());
+        break;
+      }
+    }
+  }
 
   void NoteRecentChanges::update_results()
   {
@@ -434,7 +480,7 @@ namespace gnote {
     if (sort_column >= 0) {
       // Set the sort column after loading data, since we
       // don't want to resort on every append.
-      m_store_sort->set_sort_column_id (sort_column, sort_type);
+      m_store_sort->set_sort_column(sort_column, sort_type);
     }
 
     // Restore the previous selection
@@ -482,13 +528,12 @@ namespace gnote {
         m_current_matches.clear ();
         m_store_filter->refilter ();
         update_total_note_count (m_store_sort->children().size());
-        if (m_tree->is_realized()) {
+        if (m_tree->get_realized()) {
           m_tree->scroll_to_point (0, 0);
         }
         return;
       }
-      if (!m_case_sensitive.get_active())
-        text = sharp::string_to_lower(text);
+      text = sharp::string_to_lower(text);
 
       m_current_matches.clear ();
       
@@ -498,17 +543,23 @@ namespace gnote {
         selected_notebook = notebooks::Notebook::Ptr();
       }
 
-      Search::ResultsPtr results =
-        search.search_notes(text, m_case_sensitive.get_active(), selected_notebook);
-      for(Search::Results::const_iterator iter = results->begin();
-          iter != results->end(); ++iter) {
-        m_current_matches[iter->first->uri()] = iter->second;
+      Search::ResultsPtr results = search.search_notes(text, false, selected_notebook);
+      // if no results found in current notebook ask user whether
+      // to search in all notebooks
+      if(results->size() == 0 && selected_notebook != NULL) {
+        no_matches_found_action();
       }
+      else {
+        for(Search::Results::const_iterator iter = results->begin();
+            iter != results->end(); ++iter) {
+          m_current_matches[iter->first->uri()] = iter->second;
+        }
       
-      add_matches_column ();
-      m_store_filter->refilter ();
-      m_tree->scroll_to_point (0, 0);
-      update_match_note_count (m_current_matches.size());
+        add_matches_column ();
+        m_store_filter->refilter ();
+        m_tree->scroll_to_point (0, 0);
+        update_match_note_count (m_current_matches.size());
+      }
   }
 
 
@@ -528,7 +579,7 @@ namespace gnote {
       m_matches_column->set_cell_data_func (
         *renderer,
         sigc::mem_fun(*this, &NoteRecentChanges::matches_column_data_func));
-      m_matches_column->set_sort_column_id(4);
+      m_matches_column->set_sort_column(4);
       m_matches_column->set_sort_indicator(true);
       m_matches_column->set_reorderable(false);
       m_matches_column->set_sort_order(Gtk::SORT_DESCENDING);
@@ -537,7 +588,7 @@ namespace gnote {
                                   sigc::mem_fun(*this, &NoteRecentChanges::compare_search_hits));
 
       m_tree->append_column (*m_matches_column);
-      m_store_sort->set_sort_column_id (4, Gtk::SORT_DESCENDING);
+      m_store_sort->set_sort_column(4, Gtk::SORT_DESCENDING);
     }
   }
 
@@ -550,7 +601,7 @@ namespace gnote {
     m_tree->remove_column (*m_matches_column);
     m_matches_column = NULL;
 
-    m_store_sort->set_sort_column_id (2, Gtk::SORT_DESCENDING);
+    m_store_sort->set_sort_column(2, Gtk::SORT_DESCENDING);
   }
 
 
@@ -570,7 +621,11 @@ namespace gnote {
         = m_current_matches.find(note->uri());
       if (miter != m_current_matches.end()) {
         match_count = miter->second;
-        if (match_count > 0) {
+        if(match_count == INT_MAX) {
+          //TRANSLATORS: search found a match in note title
+          match_str = _("Title match");
+        }
+        else if (match_count > 0) {
           const char * fmt;
           fmt = ngettext("%1% match", "%1% matches", match_count);
           match_str = str(boost::format(fmt) % match_count);
@@ -612,6 +667,49 @@ namespace gnote {
       ERR_OUT("exception: %s", e.what());
     }
   }
+
+  // called when no search results are found in the selected notebook
+  void NoteRecentChanges::no_matches_found_action()
+  {
+    m_hpaned.remove(m_matches_window);
+    if(!m_no_matches_box) {
+      Glib::ustring message = _("No results found in the selected notebook.\nClick here to search across all notes.");
+      Gtk::LinkButton *link_button = manage(new Gtk::LinkButton("", message));
+      link_button->signal_activate_link()
+        .connect(sigc::mem_fun(*this, &NoteRecentChanges::show_all_search_results));
+      link_button->set_tooltip_text(_("Click here to search across all notebooks"));
+      link_button->show();
+      Gtk::Table *no_matches_found_table = manage(new Gtk::Table(1, 3, false));
+      no_matches_found_table->attach(*link_button, 1, 2, 0, 1,
+        Gtk::FILL | Gtk::SHRINK,
+        Gtk::SHRINK,
+        0, 0
+      );
+
+      no_matches_found_table->set_col_spacings(4);
+      no_matches_found_table->show_all();
+      m_no_matches_box = manage(new Gtk::HBox(false, 0));
+      m_no_matches_box->pack_start(*no_matches_found_table, true, true, 0);
+      m_no_matches_box->show();
+    }
+    m_hpaned.add2(*m_no_matches_box);
+  }
+
+  void NoteRecentChanges::restore_matches_window()
+  {
+    if(m_no_matches_box && m_hpaned.get_child2() == m_no_matches_box) {
+      m_hpaned.remove(*m_no_matches_box);
+      m_hpaned.add2(m_matches_window);
+      restore_position();
+    }	
+  }
+
+  bool NoteRecentChanges::show_all_search_results()
+  {
+    Gtk::TreeIter iter = m_notebooksTree->get_model()->children().begin();
+    m_notebooksTree->get_selection()->select(iter);
+    return false;
+  }
                 
 
   /// <summary>
@@ -707,18 +805,28 @@ namespace gnote {
     perform_search ();
   }
 
-  void NoteRecentChanges::on_notes_changed(const Note::Ptr &)
+  void NoteRecentChanges::on_note_added(const Note::Ptr & note)
   {
-    update_results ();
+    restore_matches_window();
+    add_note(note);
   }
 
-  void NoteRecentChanges::on_note_renamed(const Note::Ptr&, const std::string&)
+  void NoteRecentChanges::on_note_deleted(const Note::Ptr & note)
   {
-    update_results ();
+    restore_matches_window();
+    delete_note(note);
+  }
+
+  void NoteRecentChanges::on_note_renamed(const Note::Ptr & note,
+                                          const std::string &)
+  {
+    restore_matches_window();
+    rename_note(note);
   }
 
   void NoteRecentChanges::on_note_saved(const Note::Ptr&)
   {
+    restore_matches_window();
     update_results ();
   }
 
@@ -731,7 +839,7 @@ namespace gnote {
       return;
     }
                   
-    std::vector<std::string> uris;
+    std::vector<Glib::ustring> uris;
     for(Note::List::const_iterator iter = selected_notes.begin();
         iter != selected_notes.end(); ++iter) {
 
@@ -748,7 +856,7 @@ namespace gnote {
     }
   }
 
-  void NoteRecentChanges::on_notebook_row_edited(const Glib::ustring& tree_path,
+  void NoteRecentChanges::on_notebook_row_edited(const Glib::ustring& /*tree_path*/,
                                                  const Glib::ustring& new_text)
   {
     if (notebooks::NotebookManager::instance().notebook_exists(new_text) ||
@@ -785,7 +893,7 @@ namespace gnote {
       am ["OpenNoteAction"]->property_sensitive() = false;
       am ["DeleteNoteAction"]->property_sensitive() = false;
     } 
-    else if (selected_notes.size() == 1) {
+    else if (selected_notes.size()) {
       am ["OpenNoteAction"]->property_sensitive() = true;
       am ["DeleteNoteAction"]->property_sensitive() = true;
     } 
@@ -860,8 +968,7 @@ namespace gnote {
       if (m_tree->get_selection()->is_selected(dest_path) 
           && (ev->state & (Gdk::CONTROL_MASK | Gdk::SHIFT_MASK)) == 0) {
         if (column && (ev->button == 1)) {
-          Glib::ListHandle<Gtk::CellRenderer *> renderers = column->get_cell_renderers();
-          Gtk::CellRenderer *renderer = *renderers.begin();
+          Gtk::CellRenderer *renderer = column->get_first_cell();
           Gdk::Rectangle background_area;
           m_tree->get_background_area (dest_path, *column, background_area);
           Gdk::Rectangle cell_area;
@@ -937,7 +1044,7 @@ namespace gnote {
   bool NoteRecentChanges::on_treeview_key_pressed(GdkEventKey * ev)
   {
     switch (ev->keyval) {
-    case GDK_Menu:
+    case GDK_KEY_Menu:
     {
       // Pop up the context menu if a note is selected
       Note::List selected_notes = get_selected_notes();
@@ -950,6 +1057,11 @@ namespace gnote {
       }
       break;
     }
+    case GDK_KEY_Return:
+    case GDK_KEY_KP_Enter:
+      // Open all selected notes
+      on_open_note();
+      return true;
     default:
       break;
     }
@@ -998,13 +1110,13 @@ namespace gnote {
 
     const Glib::RefPtr<Gtk::TreeSelection> selection
                                              = tree->get_selection();
-    const std::list<Gtk::TreePath> selected_rows
+    const std::vector<Gtk::TreePath> selected_rows
                                      = selection->get_selected_rows();
     if (selected_rows.empty())
       return;
 
     const Gtk::TreePath & dest_path = selected_rows.front();
-    const std::list<Gtk::TreeViewColumn *> columns
+    const std::vector<Gtk::TreeViewColumn *> columns
                                              = tree->get_columns();
     Gdk::Rectangle cell_rect;
     tree->get_cell_area (dest_path, *columns.front(), cell_rect);
@@ -1018,9 +1130,9 @@ namespace gnote {
   {
     Note::List selected_notes;
           
-    Glib::ListHandle<Gtk::TreePath, Gtk::TreePath_Traits> selected_rows =
+    std::vector<Gtk::TreePath> selected_rows =
       m_tree->get_selection()->get_selected_rows ();
-    for(Glib::ListHandle<Gtk::TreePath, Gtk::TreePath_Traits>::const_iterator iter
+    for(std::vector<Gtk::TreePath>::const_iterator iter
           = selected_rows.begin(); iter != selected_rows.end(); ++iter) {
       Note::Ptr note = get_note (*iter);
       if (!note) {
@@ -1045,10 +1157,9 @@ namespace gnote {
   void NoteRecentChanges::on_open_note()
   {
     Note::List selected_notes = get_selected_notes ();
-    if (selected_notes.size() != 1)
-      return;
-                  
-    selected_notes.front()->get_window()->present();
+    for(Note::List::iterator iter = selected_notes.begin(); iter != selected_notes.end(); ++iter) {
+      (*iter)->get_window()->present();
+    }
   }
 
   void NoteRecentChanges::on_delete_note()
@@ -1111,7 +1222,7 @@ namespace gnote {
   bool NoteRecentChanges::on_key_pressed(GdkEventKey * ev)
   {
     switch (ev->keyval) {
-    case GDK_Escape:
+    case GDK_KEY_Escape:
       // Allow Escape to close the window
       on_close_window ();
       break;
@@ -1250,6 +1361,8 @@ namespace gnote {
       m_entry_changed_timeout->reset (500);
       m_clear_search_button.set_sensitive(true);
     }
+
+    restore_matches_window();
   }
 
   // Called in after .5 seconds of typing inactivity, or on
@@ -1271,16 +1384,11 @@ namespace gnote {
     // list, or shuffling an existing term to the top...
     bool repeat = false;
 
-    if (m_case_sensitive.get_active()) {
-      repeat = (find(s_previous_searches.begin(), s_previous_searches.end(), text) != s_previous_searches.end());
-    } 
-    else {
-      std::string lower = sharp::string_to_lower(text);
-      for(std::list<std::string>::const_iterator iter = s_previous_searches.begin();
-          iter != s_previous_searches.end(); ++iter) {
-        if (sharp::string_to_lower(*iter) == lower) {
-          repeat = true;
-        }
+    std::string lower = sharp::string_to_lower(text);
+    for(std::list<std::string>::const_iterator iter = s_previous_searches.begin();
+        iter != s_previous_searches.end(); ++iter) {
+      if (sharp::string_to_lower(*iter) == lower) {
+        repeat = true;
       }
     }
 
@@ -1346,6 +1454,7 @@ namespace gnote {
 
   void NoteRecentChanges::on_notebook_selection_changed()
   {
+    restore_matches_window();
     notebooks::Notebook::Ptr notebook = get_selected_notebook ();
     ActionManager & am(ActionManager::obj());
     if (!notebook) {
@@ -1374,8 +1483,8 @@ namespace gnote {
         allow_edit = true;
       }
 
-      Glib::ListHandle<Gtk::CellRenderer*> renderers = m_notebooksTree->get_column(0)->get_cell_renderers();
-      for (Glib::ListHandle<Gtk::CellRenderer*>::iterator renderer = renderers.begin();
+      std::vector<Gtk::CellRenderer*> renderers = m_notebooksTree->get_column(0)->get_cells();
+      for (std::vector<Gtk::CellRenderer*>::iterator renderer = renderers.begin();
            renderer != renderers.end(); ++renderer) {
         Gtk::CellRendererText *text_rederer = dynamic_cast<Gtk::CellRendererText*>(*renderer);
         if (text_rederer) {
@@ -1501,7 +1610,7 @@ namespace gnote {
   bool NoteRecentChanges::on_notebooks_key_pressed(GdkEventKey * ev)
   {
     switch (ev->keyval) {
-    case GDK_Menu:
+    case GDK_KEY_Menu:
     {
       // Pop up the context menu if a notebook is selected
       notebooks::Notebook::Ptr notebook = get_selected_notebook ();
@@ -1524,12 +1633,14 @@ namespace gnote {
   void NoteRecentChanges::on_note_added_to_notebook (const Note & , 
                                                      const notebooks::Notebook::Ptr & )
   {
+    restore_matches_window();
     update_results ();
   }
     
   void NoteRecentChanges::on_note_removed_from_notebook (const Note & , 
                                                        const notebooks::Notebook::Ptr & )
   {
+    restore_matches_window();
     update_results ();
   }
 
@@ -1564,25 +1675,26 @@ namespace gnote {
 
     get_position(x, y);
     get_size(width, height);
-     
-    Preferences & prefs(Preferences::obj());
-    prefs.set<int> (Preferences::SEARCH_WINDOW_X_POS, x);
-    prefs.set<int> (Preferences::SEARCH_WINDOW_Y_POS, y);
-    prefs.set<int> (Preferences::SEARCH_WINDOW_WIDTH, width);
-    prefs.set<int> (Preferences::SEARCH_WINDOW_HEIGHT, height);
-    prefs.set<int> (Preferences::SEARCH_WINDOW_SPLITTER_POS, 
-                    m_hpaned.get_position());
+
+    Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+      .get_schema_settings(Preferences::SCHEMA_GNOTE);
+    settings->set_int(Preferences::SEARCH_WINDOW_X_POS, x);
+    settings->set_int(Preferences::SEARCH_WINDOW_Y_POS, y);
+    settings->set_int(Preferences::SEARCH_WINDOW_WIDTH, width);
+    settings->set_int(Preferences::SEARCH_WINDOW_HEIGHT, height);
+    settings->set_int(Preferences::SEARCH_WINDOW_SPLITTER_POS, m_hpaned.get_position());
   }
         
    
   void NoteRecentChanges::restore_position()
   {
-    Preferences & prefs(Preferences::obj());
-    int x = prefs.get<int> (Preferences::SEARCH_WINDOW_X_POS);
-    int y = prefs.get<int> (Preferences::SEARCH_WINDOW_Y_POS);
-    int width = prefs.get<int> (Preferences::SEARCH_WINDOW_WIDTH);
-    int height = prefs.get<int> (Preferences::SEARCH_WINDOW_HEIGHT);
-    int pos = prefs.get<int> (Preferences::SEARCH_WINDOW_SPLITTER_POS);
+    Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+      .get_schema_settings(Preferences::SCHEMA_GNOTE);
+    int x = settings->get_int(Preferences::SEARCH_WINDOW_X_POS);
+    int y = settings->get_int(Preferences::SEARCH_WINDOW_Y_POS);
+    int width = settings->get_int(Preferences::SEARCH_WINDOW_WIDTH);
+    int height = settings->get_int(Preferences::SEARCH_WINDOW_HEIGHT);
+    int pos = settings->get_int(Preferences::SEARCH_WINDOW_SPLITTER_POS);
 
     if((width == 0) || (height == 0)) {
       return;
@@ -1596,10 +1708,9 @@ namespace gnote {
   }
 
 
-  bool NoteRecentChanges::on_exiting_event()
+  void NoteRecentChanges::on_exiting_event()
   {
     save_position();
-    return false;
   }
 
 }
