@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010 Aurimas Cernius
+ * Copyright (C) 2010-2011 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -58,8 +58,7 @@ namespace gnote {
                               int & y,
                               bool & push_in)
       {
-        if (menu->get_attach_widget() == NULL ||
-            menu->get_attach_widget()->get_window() == NULL) {
+        if (!menu->get_attach_widget() || !menu->get_attach_widget()->get_window()) {
           // Prevent null exception in weird cases
           x = 0;
           y = 0;
@@ -70,7 +69,8 @@ namespace gnote {
         menu->get_attach_widget()->get_window()->get_origin(x, y);
         x += menu->get_attach_widget()->get_allocation().get_x();
         
-        Gtk::Requisition menu_req = menu->size_request();
+        Gtk::Requisition menu_req, unused;
+        menu->get_preferred_size(unused, menu_req);
         if (y + menu_req.height >= menu->get_attach_widget()->get_screen()->get_height()) {
           y -= menu_req.height;
         }
@@ -276,7 +276,6 @@ namespace gnote {
       : Gtk::Dialog()
       , m_extra_widget(NULL)
     {
-      set_has_separator(false);
       set_border_width(5);
       set_resizable(false);
       set_title("");
@@ -422,7 +421,7 @@ namespace gnote {
       if (is_default) {
         set_default_response(resp);
         button->add_accelerator ("activate", m_accel_group,
-                                 GDK_Escape, (Gdk::ModifierType)0,
+                                 GDK_KEY_Escape, (Gdk::ModifierType)0,
                                  Gtk::ACCEL_VISIBLE);
       }
     }
@@ -453,12 +452,17 @@ namespace gnote {
     {
       std::vector<std::string> items;
       sharp::string_split(items, data, "\n");
-      load_from_string_list(items);
+      std::vector<Glib::ustring> uitems;
+      for(std::vector<std::string>::iterator iter = items.begin();
+          iter != items.end(); ++iter) {
+        uitems.push_back(*iter);
+      }
+      load_from_string_list(uitems);
     }
 
-    void UriList::load_from_string_list(const std::vector<std::string> & items)
+    void UriList::load_from_string_list(const std::vector<Glib::ustring> & items)
     {
-      for(std::vector<std::string>::const_iterator iter = items.begin();
+      for(std::vector<Glib::ustring>::const_iterator iter = items.begin();
           iter != items.end(); ++iter) {
 
         const std::string & i(*iter);
@@ -749,7 +753,7 @@ namespace gnote {
       if (!group_cycling) {
         activate();
       } 
-      else if (can_focus()) {
+      else if (get_can_focus()) {
         grab_focus();
       }
 
